@@ -31,7 +31,7 @@ estimate_timeout <- function(url, factor = 1, perMB = 10)
 .get_content_length <- function(url, verbose = FALSE)
 {
     url_base <- "https://wwwn.cdc.gov"
-    if (!startsWith(url, "/Nchs/Nhanes")) {
+    if (!startsWith(tolower(url), "/nchs/")) {
         if (verbose) message("SKIPPING ", url)
         return(NA_real_)
     }
@@ -55,6 +55,9 @@ estimate_timeout <- function(url, factor = 1, perMB = 10)
 ##'   available variables.
 ##' @param sizes Logical, whether to compute data file sizes (as
 ##'   reported by the server) and include them in the result.
+##' @param dxa Logical, whether to include information on DXA tables.
+##'   These tables contain imputed imputed Dual Energy X-ray Absorptiometry
+##'   measurements, and are listed separately, not in the main listing.
 ##' @param verbose Logical flag indicating whether information on
 ##'   progress should be reported.
 ##' @param use_cache Logical flag indicating whether a cached version
@@ -84,11 +87,13 @@ estimate_timeout <- function(url, factor = 1, perMB = 10)
 ##' 
 ##' @export
 nhanesManifest <- function(which = c("public", "limitedaccess", "variables"),
-                           sizes = FALSE, verbose = getOption("verbose"),
+                           sizes = FALSE, dxa = FALSE,
+                           verbose = getOption("verbose"),
                            use_cache = TRUE, max_age = 24 * 60 * 60)
 {
   which <- match.arg(which)
-  cache_key <- if (which == "public" && isTRUE(sizes)) "public+sizes"
+  cache_key <- if (which == "public")
+                   paste(c("public", "sizes", "dxa")[c(TRUE, sizes, dxa)], collapse = "+")
                else which
   if (isTRUE(use_cache)) {
     cache_val <- .nhanesCacheEnv[[ cache_key ]]
@@ -100,7 +105,9 @@ nhanesManifest <- function(which = c("public", "limitedaccess", "variables"),
   ## otherwise, fresh download
   ans <- 
     switch(which,
-           public = nhanesManifest_public(sizes = sizes, verbose = verbose),
+           public = if (dxa) rbind(nhanesManifest_public(sizes = sizes, verbose = verbose),
+                                   nhanesManifest_DXA_hardcoded(sizes))
+                    else nhanesManifest_public(sizes = sizes, verbose = verbose),
            limitedaccess = nhanesManifest_limitedaccess(verbose = verbose),
            variables = nhanesManifest_variables(verbose = verbose)) |>
       unique()
@@ -148,6 +155,65 @@ nhanesManifest_public <- function(sizes, verbose)
   return(df)
 }
 
+
+## We can use the following function to get the DXA table details from
+## https://wwwn.cdc.gov/Nchs/Nhanes/Dxa/Dxa.aspx. However, one problem
+## with this approach is that the Doc files for DXA, DXA_B, and DXA_C
+## are PDF files which we cannot parse, and only the DXA_D doc is
+## HTML. The workaround is to use the DXA_D doc / codebook for all
+## four. We do this by maintaining a hard-coded version of the result,
+## assuming that the information will not change going forward (the
+## last update happened in 2016).
+
+nhanesManifest_DXA <- function(sizes, verbose)
+{
+  if (verbose) message("Downloading ", dxaTablesURL)
+  hurl <- .checkHtml(dxaTablesURL)
+  if(is.null(hurl)) {
+    message("Error occurred during read. No tables returned")
+    return(NULL)
+  }
+  ##get to the table
+  xpath <- '//*[@id="GridView1"]'
+  tab1 <- hurl |> html_elements(xpath=xpath)
+  ##pull out all the hrefs
+  hrefs <- tab1 |> html_nodes("a") |> html_attr("href")
+  df <- tab1 |> html_table() |> as.data.frame()
+  df$Table <- sub(" Doc", "", df$Doc.File)
+  ## make sure lengths now match
+  if (nrow(df) * 2 != length(hrefs)) stop("Wrong number of URLs in table manifest")
+  df$DocURL <- hrefs[c(TRUE, FALSE)]
+  df$DataURL <- hrefs[c(FALSE, TRUE)]
+  ## subset(df, tools::file_ext(DataURL) != "XPT")
+  df <- subset(df, startsWith(DataURL, "/") & endsWith(toupper(DataURL), ".XPT"))
+  df <- df[c("Table", "DocURL", "DataURL", "Years", "Date.Published")]
+  if (sizes) {
+    if (verbose) message("Checking data file sizes...")
+    s <- sapply(df$DataURL, .get_content_length, verbose = verbose)
+    df$DataSize <- s
+  }
+  return(df)
+}
+
+nhanesManifest_DXA_hardcoded <- function(sizes, verbose)
+{
+    keep <- if (isTRUE(sizes)) 1:6 else 1:5
+    ## manually edited from nhanesManifest_DXA(sizes = TRUE)
+    data.frame(Table = c("DXX_D", "DXX_C", "DXX_B", "DXX"),
+               DocURL = rep("/nchs/data/nhanes/dxa/dxx_d.htm", 4),
+               DataURL = c("/nchs/data/nhanes/dxa/dxx_d.xpt", 
+                           "/nchs/data/nhanes/dxa/dxx_c.xpt",
+                           "/nchs/data/nhanes/dxa/dxx_b.xpt", 
+                           "/nchs/data/nhanes/dxa/dxx.xpt"),
+               Years = c("2005-2006", "2003-2004", 
+                         "2001-2002", "1999-2000"),
+               Date.Published = c("Updated December 2016", 
+                                  "Updated March 2010",
+                                  "Updated March 2010",
+                                  "Updated March 2010"),
+               DataSize = c(29517840, 30371680, 32695200, 24737440))[keep]
+}
+
 nhanesManifest_limitedaccess <- function(verbose)
 {
   if (verbose) message("Downloading ", ladDataURL)
@@ -231,6 +297,7 @@ parseRedirect <- function(s, prefix = "../vitamind/analyticalnote.aspx?")
 {
   ans <- s
   tofix <- startsWith(tolower(s), tolower(prefix))
+  if (!any(tofix)) return(s)
   ss <- substring(s[tofix], 1 + nchar(prefix), 999)
   ss <- sapply(ss, string2url)
   ans[tofix] <- ss
